==========
Attributes
==========

.. currentmodule:: polars
.. autosummary::
   :toctree: api/
   :template: autosummary/accessor_attribute.rst

   Series.dtype
   Series.inner_dtype
   Series.name
   Series.shape
   Series.flags
